==> epyk-1.5.0-py2.py3-none-any.whl: epyk/core/css/styles/classes/CssStylesIcon.py <==
"""
CSS Style module for the Icons components
"""

from epyk.core.css.styles.classes import CssStyle

from epyk.core.css import Defaults as Defaults_css


class CssIcon(CssStyle.Style):
  _attrs = {'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.colors[-1]})
    self.hover.css({"color": self.page.theme.success[1]})


class CssStdIcon(CssStyle.Style):
  _attrs = {'cursor': 'pointer'}

  def customize(self):
    self.hover.css({"color": self.page.theme.success[1]})


class CssSmallIcon(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 5px 0 0', 'cursor': 'pointer'}

  def customize(self):
    self.hover.css({"color": self.page.theme.colors[5],
                    'font-size': '%s%s' % (Defaults_css.Icon.small, Defaults_css.Icon.unit)})


class CssSmallIconRight(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 0 0 5px', 'cursor': 'pointer', 'float': 'right'}

  def customize(self):
    self.hover.css({"color": self.page.theme.colors[5],
                    'font-size': '%s%s' % (Defaults_css.Icon.small, Defaults_css.Icon.unit)})


class CssSmallIconRed(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 5px 0 0', 'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.danger[1],
              'font-size': '%s%s' % (Defaults_css.Icon.small, Defaults_css.Icon.unit)})
    self.hover.css({"color": self.page.theme.danger[1]})


class CssOutIcon(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 0 0 20px', 'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.danger[1],
              'font-size': '%s%s' % (Defaults_css.Icon.normal, Defaults_css.Icon.unit)})
    self.hover.css({"color": self.page.theme.danger[1]})


class CssBigIcon(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 10px 0 10px', 'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.danger[1],
              'font-size': '%s%s' % (Defaults_css.Icon.big, Defaults_css.Icon.unit)})
    self.hover.css({"color": self.page.theme.danger[1]})


class CssIconSelected(CssStyle.Style):
  _attrs = {'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.greys[-1]})
    self.active.css({"color": self.page.theme.danger[1]})

==> epyk-1.6.9-py2.py3-none-any.whl: epyk/core/css/styles/classes/CssStylesIcon.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

from epyk.core.css.styles.classes import CssStyle


class CssIcon(CssStyle.Style):
  _attrs = {'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.colors[-1]})
    self.hover.css({"color": self.page.theme.notch()})


class CssStdIcon(CssStyle.Style):
  _attrs = {'cursor': 'pointer'}

  def customize(self):
    self.hover.css({"color": self.page.theme.success[1]})


class CssSmallIcon(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 5px 0 0', 'cursor': 'pointer'}

  def customize(self):
    self.hover.css({"color": self.page.theme.notch(),
                    'font-size': self.page.body.style.globals.icon.small_size()})


class CssSmallIconRight(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 0 0 5px', 'cursor': 'pointer', 'float': 'right'}

  def customize(self):
    self.hover.css({"color": self.page.theme.notch(),
                    'font-size': self.page.body.style.globals.icon.small_size()})


class CssSmallIconRed(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 5px 0 0', 'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.danger[1],
              'font-size': self.page.body.style.globals.icon.small_size()})
    self.hover.css({"color": self.page.theme.danger[1]})


class CssOutIcon(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 0 0 20px', 'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.danger[1],
              'font-size': self.page.body.style.globals.icon.normal_size()})
    self.hover.css({"color": self.page.theme.danger[1]})


class CssBigIcon(CssStyle.Style):
  _attrs = {'display': 'inline-block', 'margin': '0 10px 0 10px', 'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.danger[1],
              'font-size': self.page.body.style.globals.icon.big_size()})
    self.hover.css({"color": self.page.theme.danger[1]})


class CssIconSelected(CssStyle.Style):
  _attrs = {'cursor': 'pointer'}

  def customize(self):
    self.css({"color": self.page.theme.greys[-1]})
    self.active.css({"color": self.page.theme.danger[1]})
